/*************************************************** -*- tab-width:4 -*- *
 * Clear number or insert number at cursor.                              *
 * Goto Column                                                           *
 * Wayne Dow, June 11, 2013                                              *
**************************************************************************/

// This is a function that will increment and insert a number.
// The goto column function prompts for a column number then jumps to that
// column inserting spaces if needed.

#include "eel.h"

char *charname_matcher(char *s, int flags);

/* To define an external variable
just define it as usual in both files:
int foo; It's fine if multiple EEL files define the same variable,
so there's no need to use "extern" as in C.
Typically variables would be defined in a .h file, and all the .e files would include it,
but you can also have them all define it individually.
*/

int ins_num;

/* clear number
 * June 6, 2013 change default setting
 */
command clear_number()
{
    ins_num = 0;
}

/* insert number at point
 * then increment the number
 */
command insert_number()
{
    char pat[10];
    int i;
    sprintf(pat, "%d", ins_num);
    i = 0;
    while (i < 10 && pat[i])
        insert(pat[i++]);
    /* add the following */
    ins_num++;
}

/* increment number */
command inc_number()
{
    ins_num++;
}

/* set number
 * June 6, 2013
 */
command set_number()
{
    int res;
    char buf[10];

    comp_read(buf, "Insert Number: ",
              charname_matcher, COMP_FOLD | SPACE_VALID, "");

    res = exptoi(buf);
    if (res < 1 || res > 200)
        error("Invalid Column %s.", buf);

    ins_num = res;
}

command goto_column()
{
    int res;
    int end_col;
    char buf[10];

    comp_read(buf, "Insert column number: ",
              charname_matcher, COMP_FOLD | SPACE_VALID, "");

    res = exptoi(buf);
    if (res < 1 || res > 200)
        error("Invalid Column %s.", buf);

    //goto the end of this line
    end_of_line();
    end_col = current_column();

    if (res < end_col)
    {
        to_virtual_column(res);
    }
    else
    {
        while (end_col < res)
        {
            end_col++;
            insert(' ');
        }
    }
}

